==> haskell-unixutils-1.54.1-42-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-unixutils.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: Unixutils
version: 1.54.1
id: Unixutils-1.54.1-FwpLD2HuxPs4T3MPHmo8PZ
key: Unixutils-1.54.1-FwpLD2HuxPs4T3MPHmo8PZ
license: BSD-3-Clause
maintainer: jeremy@n-heptane.com
author: Jeremy Shaw, David Fox
homepage: https://github.com/seereason/haskell-unixutils.git
synopsis: A crude interface between Haskell and Unix-like operating systems
description:
    A collection of useful and mildly useful functions that you might
    expect to find in System.* which a heavy bias towards Unix-type operating systems.
category: System
abi: ad5edd4585a9cc253bb7edd6654dd144
exposed: True
exposed-modules:
    System.Unix.Chroot System.Unix.Crypt System.Unix.Directory
    System.Unix.FilePath System.Unix.Files System.Unix.KillByCwd
    System.Unix.Misc System.Unix.Mount System.Unix.SpecialDevice
import-dirs: /usr/lib/ghc-8.4.3/site-local/Unixutils-1.54.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/Unixutils-1.54.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/Unixutils-1.54.1
hs-libraries: HSUnixutils-1.54.1-FwpLD2HuxPs4T3MPHmo8PZ
extra-libraries:
    crypt
depends:
    base-4.11.1.0 bytestring-0.10.8.2 directory-1.3.1.5
    exceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf filepath-1.4.2 mtl-2.2.2
    process-1.6.3.0 process-extras-0.7.4-KpSQV8bjKJvKU7mDGVRIAK
    pureMD5-2.1.3-DN0w3GcDEOqAjLnXb2fZPW
    regex-tdfa-1.2.3-1e6W0u5rRmsDEmJafeJHae unix-2.7.2.2
    zlib-0.6.2-HJOgVWrPGFTFgWXcvoaUGH
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             exceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf=7910067871295cb7f4f6699a852863a6
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             process-1.6.3.0=b58285e21ceee9f67d7be28ddb8b2627
             process-extras-0.7.4-KpSQV8bjKJvKU7mDGVRIAK=2ffb3d5e44bb7dc3f51b49e1bb8e80ef
             pureMD5-2.1.3-DN0w3GcDEOqAjLnXb2fZPW=b95425c23cd6458fb08cc2f45008c97e
             regex-tdfa-1.2.3-1e6W0u5rRmsDEmJafeJHae=e64f7247eeed810d7f79ae6f49e42740
             unix-2.7.2.2=f81aa481840dadf9c364a1cea96978c0
             zlib-0.6.2-HJOgVWrPGFTFgWXcvoaUGH=8fa648805d93281f19b98bbf203b4b1c
haddock-interfaces: /usr/share/doc/haskell-unixutils/html/Unixutils.haddock
haddock-html: /usr/share/doc/haskell-unixutils/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unixutils-1.54.1-44-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-unixutils.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: Unixutils
version: 1.54.1
id: Unixutils-1.54.1-EEUu6Eex9rd1VwqEPyJUk
key: Unixutils-1.54.1-EEUu6Eex9rd1VwqEPyJUk
license: BSD-3-Clause
maintainer: jeremy@n-heptane.com
author: Jeremy Shaw, David Fox
homepage: https://github.com/seereason/haskell-unixutils.git
synopsis: A crude interface between Haskell and Unix-like operating systems
description:
    A collection of useful and mildly useful functions that you might
    expect to find in System.* which a heavy bias towards Unix-type operating systems.
category: System
abi: 527c6c68ea8657a16065d6643197bf6e
exposed: True
exposed-modules:
    System.Unix.Chroot System.Unix.Crypt System.Unix.Directory
    System.Unix.FilePath System.Unix.Files System.Unix.KillByCwd
    System.Unix.Misc System.Unix.Mount System.Unix.SpecialDevice
import-dirs: /usr/lib/ghc-8.4.3/site-local/Unixutils-1.54.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/Unixutils-1.54.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/Unixutils-1.54.1
hs-libraries: HSUnixutils-1.54.1-EEUu6Eex9rd1VwqEPyJUk
extra-libraries:
    crypt
depends:
    base-4.11.1.0 bytestring-0.10.8.2 directory-1.3.1.5
    exceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf filepath-1.4.2 mtl-2.2.2
    process-1.6.3.0 process-extras-0.7.4-EB4TYKi0OUxEIDlRLR3Dc7
    pureMD5-2.1.3-DN0w3GcDEOqAjLnXb2fZPW
    regex-tdfa-1.2.3.1-az1JL7mhmZBLFmoReK21K unix-2.7.2.2
    zlib-0.6.2-HJOgVWrPGFTFgWXcvoaUGH
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             exceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf=7910067871295cb7f4f6699a852863a6
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             process-1.6.3.0=b58285e21ceee9f67d7be28ddb8b2627
             process-extras-0.7.4-EB4TYKi0OUxEIDlRLR3Dc7=fa85e3ad216059a6de4983e27a850c62
             pureMD5-2.1.3-DN0w3GcDEOqAjLnXb2fZPW=b95425c23cd6458fb08cc2f45008c97e
             regex-tdfa-1.2.3.1-az1JL7mhmZBLFmoReK21K=98feb6ae4c5e833326f77c1995f4743b
             unix-2.7.2.2=f81aa481840dadf9c364a1cea96978c0
             zlib-0.6.2-HJOgVWrPGFTFgWXcvoaUGH=8fa648805d93281f19b98bbf203b4b1c
haddock-interfaces: /usr/share/doc/haskell-unixutils/html/Unixutils.haddock
haddock-html: /usr/share/doc/haskell-unixutils/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
